# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Iterable

import httpx

from ..types import identity_create_params, identity_update_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.identity_create_response import IdentityCreateResponse
from ..types.identity_delete_response import IdentityDeleteResponse
from ..types.identity_update_response import IdentityUpdateResponse
from ..types.identity_retrieve_response import IdentityRetrieveResponse
from ..types.identity_retrieve_credentials_response import IdentityRetrieveCredentialsResponse

__all__ = ["IdentitiesResource", "AsyncIdentitiesResource"]


class IdentitiesResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> IdentitiesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#accessing-raw-response-data-eg-headers
        """
        return IdentitiesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> IdentitiesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#with_streaming_response
        """
        return IdentitiesResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        credentials: Iterable[identity_create_params.Credential],
        source: str,
        validate_async: bool | Omit = omit,
        application_description: str | Omit = omit,
        application_name: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityCreateResponse:
        """Creates a new identity with credentials for authentication.

        **Beta** Capability.

        [Contact support](mailto:support@anchorbrowser.io) to
        enable.

        Args:
          credentials: Array of credentials for authentication

          source: The source URL for the identity (e.g., login page URL)

          validate_async: Whether to validate the identity asynchronously. Defaults to true.

          application_description: Optional application description

          application_name: Optional application name to associate with the identity

          metadata: Optional metadata for the identity

          name: Name of the identity. Defaults to "Unnamed Identity" if not provided.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/v1/identities",
            body=maybe_transform(
                {
                    "credentials": credentials,
                    "source": source,
                    "application_description": application_description,
                    "application_name": application_name,
                    "metadata": metadata,
                    "name": name,
                },
                identity_create_params.IdentityCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"validate_async": validate_async}, identity_create_params.IdentityCreateParams),
            ),
            cast_to=IdentityCreateResponse,
        )

    def retrieve(
        self,
        identity_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityRetrieveResponse:
        """Retrieves details of a specific identity by its ID.

        **Beta** Capability.

        [Contact support](mailto:support@anchorbrowser.io) to
        enable.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not identity_id:
            raise ValueError(f"Expected a non-empty value for `identity_id` but received {identity_id!r}")
        return self._get(
            f"/v1/identities/{identity_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityRetrieveResponse,
        )

    def update(
        self,
        identity_id: str,
        *,
        credentials: Iterable[identity_update_params.Credential] | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityUpdateResponse:
        """
        Updates an existing identity's name, metadata, or credentials.

        **Beta** Capability. [Contact support](mailto:support@anchorbrowser.io) to
        enable.

        Args:
          credentials: Array of credentials for authentication

          metadata: Metadata for the identity

          name: Name of the identity

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not identity_id:
            raise ValueError(f"Expected a non-empty value for `identity_id` but received {identity_id!r}")
        return self._put(
            f"/v1/identities/{identity_id}",
            body=maybe_transform(
                {
                    "credentials": credentials,
                    "metadata": metadata,
                    "name": name,
                },
                identity_update_params.IdentityUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityUpdateResponse,
        )

    def delete(
        self,
        identity_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityDeleteResponse:
        """Deletes an existing identity.

        **Beta** Capability.

        [Contact support](mailto:support@anchorbrowser.io) to
        enable.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not identity_id:
            raise ValueError(f"Expected a non-empty value for `identity_id` but received {identity_id!r}")
        return self._delete(
            f"/v1/identities/{identity_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityDeleteResponse,
        )

    def retrieve_credentials(
        self,
        identity_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityRetrieveCredentialsResponse:
        """
        Retrieves the credentials for a specific identity.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not identity_id:
            raise ValueError(f"Expected a non-empty value for `identity_id` but received {identity_id!r}")
        return self._get(
            f"/v1/identities/{identity_id}/credentials",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityRetrieveCredentialsResponse,
        )


class AsyncIdentitiesResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncIdentitiesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#accessing-raw-response-data-eg-headers
        """
        return AsyncIdentitiesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncIdentitiesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/anchorbrowser/AnchorBrowser-SDK-Python#with_streaming_response
        """
        return AsyncIdentitiesResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        credentials: Iterable[identity_create_params.Credential],
        source: str,
        validate_async: bool | Omit = omit,
        application_description: str | Omit = omit,
        application_name: str | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityCreateResponse:
        """Creates a new identity with credentials for authentication.

        **Beta** Capability.

        [Contact support](mailto:support@anchorbrowser.io) to
        enable.

        Args:
          credentials: Array of credentials for authentication

          source: The source URL for the identity (e.g., login page URL)

          validate_async: Whether to validate the identity asynchronously. Defaults to true.

          application_description: Optional application description

          application_name: Optional application name to associate with the identity

          metadata: Optional metadata for the identity

          name: Name of the identity. Defaults to "Unnamed Identity" if not provided.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/v1/identities",
            body=await async_maybe_transform(
                {
                    "credentials": credentials,
                    "source": source,
                    "application_description": application_description,
                    "application_name": application_name,
                    "metadata": metadata,
                    "name": name,
                },
                identity_create_params.IdentityCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"validate_async": validate_async}, identity_create_params.IdentityCreateParams
                ),
            ),
            cast_to=IdentityCreateResponse,
        )

    async def retrieve(
        self,
        identity_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityRetrieveResponse:
        """Retrieves details of a specific identity by its ID.

        **Beta** Capability.

        [Contact support](mailto:support@anchorbrowser.io) to
        enable.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not identity_id:
            raise ValueError(f"Expected a non-empty value for `identity_id` but received {identity_id!r}")
        return await self._get(
            f"/v1/identities/{identity_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityRetrieveResponse,
        )

    async def update(
        self,
        identity_id: str,
        *,
        credentials: Iterable[identity_update_params.Credential] | Omit = omit,
        metadata: Dict[str, object] | Omit = omit,
        name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityUpdateResponse:
        """
        Updates an existing identity's name, metadata, or credentials.

        **Beta** Capability. [Contact support](mailto:support@anchorbrowser.io) to
        enable.

        Args:
          credentials: Array of credentials for authentication

          metadata: Metadata for the identity

          name: Name of the identity

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not identity_id:
            raise ValueError(f"Expected a non-empty value for `identity_id` but received {identity_id!r}")
        return await self._put(
            f"/v1/identities/{identity_id}",
            body=await async_maybe_transform(
                {
                    "credentials": credentials,
                    "metadata": metadata,
                    "name": name,
                },
                identity_update_params.IdentityUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityUpdateResponse,
        )

    async def delete(
        self,
        identity_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityDeleteResponse:
        """Deletes an existing identity.

        **Beta** Capability.

        [Contact support](mailto:support@anchorbrowser.io) to
        enable.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not identity_id:
            raise ValueError(f"Expected a non-empty value for `identity_id` but received {identity_id!r}")
        return await self._delete(
            f"/v1/identities/{identity_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityDeleteResponse,
        )

    async def retrieve_credentials(
        self,
        identity_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> IdentityRetrieveCredentialsResponse:
        """
        Retrieves the credentials for a specific identity.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not identity_id:
            raise ValueError(f"Expected a non-empty value for `identity_id` but received {identity_id!r}")
        return await self._get(
            f"/v1/identities/{identity_id}/credentials",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=IdentityRetrieveCredentialsResponse,
        )


class IdentitiesResourceWithRawResponse:
    def __init__(self, identities: IdentitiesResource) -> None:
        self._identities = identities

        self.create = to_raw_response_wrapper(
            identities.create,
        )
        self.retrieve = to_raw_response_wrapper(
            identities.retrieve,
        )
        self.update = to_raw_response_wrapper(
            identities.update,
        )
        self.delete = to_raw_response_wrapper(
            identities.delete,
        )
        self.retrieve_credentials = to_raw_response_wrapper(
            identities.retrieve_credentials,
        )


class AsyncIdentitiesResourceWithRawResponse:
    def __init__(self, identities: AsyncIdentitiesResource) -> None:
        self._identities = identities

        self.create = async_to_raw_response_wrapper(
            identities.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            identities.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            identities.update,
        )
        self.delete = async_to_raw_response_wrapper(
            identities.delete,
        )
        self.retrieve_credentials = async_to_raw_response_wrapper(
            identities.retrieve_credentials,
        )


class IdentitiesResourceWithStreamingResponse:
    def __init__(self, identities: IdentitiesResource) -> None:
        self._identities = identities

        self.create = to_streamed_response_wrapper(
            identities.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            identities.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            identities.update,
        )
        self.delete = to_streamed_response_wrapper(
            identities.delete,
        )
        self.retrieve_credentials = to_streamed_response_wrapper(
            identities.retrieve_credentials,
        )


class AsyncIdentitiesResourceWithStreamingResponse:
    def __init__(self, identities: AsyncIdentitiesResource) -> None:
        self._identities = identities

        self.create = async_to_streamed_response_wrapper(
            identities.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            identities.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            identities.update,
        )
        self.delete = async_to_streamed_response_wrapper(
            identities.delete,
        )
        self.retrieve_credentials = async_to_streamed_response_wrapper(
            identities.retrieve_credentials,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .shared import SuccessResponse as SuccessResponse
from .task_run_params import TaskRunParams as TaskRunParams
from .task_list_params import TaskListParams as TaskListParams
from .task_run_response import TaskRunResponse as TaskRunResponse
from .extension_manifest import ExtensionManifest as ExtensionManifest
from .task_create_params import TaskCreateParams as TaskCreateParams
from .task_list_response import TaskListResponse as TaskListResponse
from .event_signal_params import EventSignalParams as EventSignalParams
from .session_goto_params import SessionGotoParams as SessionGotoParams
from .task_create_response import TaskCreateResponse as TaskCreateResponse
from .event_wait_for_params import EventWaitForParams as EventWaitForParams
from .profile_create_params import ProfileCreateParams as ProfileCreateParams
from .profile_list_response import ProfileListResponse as ProfileListResponse
from .session_create_params import SessionCreateParams as SessionCreateParams
from .session_goto_response import SessionGotoResponse as SessionGotoResponse
from .session_scroll_params import SessionScrollParams as SessionScrollParams
from .identity_create_params import IdentityCreateParams as IdentityCreateParams
from .identity_update_params import IdentityUpdateParams as IdentityUpdateParams
from .application_list_params import ApplicationListParams as ApplicationListParams
from .event_wait_for_response import EventWaitForResponse as EventWaitForResponse
from .extension_list_response import ExtensionListResponse as ExtensionListResponse
from .session_create_response import SessionCreateResponse as SessionCreateResponse
from .session_scroll_response import SessionScrollResponse as SessionScrollResponse
from .identity_create_response import IdentityCreateResponse as IdentityCreateResponse
from .identity_delete_response import IdentityDeleteResponse as IdentityDeleteResponse
from .identity_update_response import IdentityUpdateResponse as IdentityUpdateResponse
from .application_create_params import ApplicationCreateParams as ApplicationCreateParams
from .application_list_response import ApplicationListResponse as ApplicationListResponse
from .profile_retrieve_response import ProfileRetrieveResponse as ProfileRetrieveResponse
from .session_retrieve_response import SessionRetrieveResponse as SessionRetrieveResponse
from .tool_fetch_webpage_params import ToolFetchWebpageParams as ToolFetchWebpageParams
from .identity_retrieve_response import IdentityRetrieveResponse as IdentityRetrieveResponse
from .session_upload_file_params import SessionUploadFileParams as SessionUploadFileParams
from .application_create_response import ApplicationCreateResponse as ApplicationCreateResponse
from .application_delete_response import ApplicationDeleteResponse as ApplicationDeleteResponse
from .tool_fetch_webpage_response import ToolFetchWebpageResponse as ToolFetchWebpageResponse
from .session_drag_and_drop_params import SessionDragAndDropParams as SessionDragAndDropParams
from .session_upload_file_response import SessionUploadFileResponse as SessionUploadFileResponse
from .tool_perform_web_task_params import ToolPerformWebTaskParams as ToolPerformWebTaskParams
from .application_retrieve_response import ApplicationRetrieveResponse as ApplicationRetrieveResponse
from .session_drag_and_drop_response import SessionDragAndDropResponse as SessionDragAndDropResponse
from .tool_perform_web_task_response import ToolPerformWebTaskResponse as ToolPerformWebTaskResponse
from .tool_screenshot_webpage_params import ToolScreenshotWebpageParams as ToolScreenshotWebpageParams
from .application_list_identities_params import ApplicationListIdentitiesParams as ApplicationListIdentitiesParams
from .session_retrieve_downloads_response import SessionRetrieveDownloadsResponse as SessionRetrieveDownloadsResponse
from .application_list_identities_response import ApplicationListIdentitiesResponse as ApplicationListIdentitiesResponse
from .identity_retrieve_credentials_response import (
    IdentityRetrieveCredentialsResponse as IdentityRetrieveCredentialsResponse,
)
from .application_create_identity_token_params import (
    ApplicationCreateIdentityTokenParams as ApplicationCreateIdentityTokenParams,
)
from .application_create_identity_token_response import (
    ApplicationCreateIdentityTokenResponse as ApplicationCreateIdentityTokenResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .auth_flow_create_params import AuthFlowCreateParams as AuthFlowCreateParams
from .auth_flow_list_response import AuthFlowListResponse as AuthFlowListResponse
from .auth_flow_update_params import AuthFlowUpdateParams as AuthFlowUpdateParams
from .auth_flow_create_response import AuthFlowCreateResponse as AuthFlowCreateResponse
from .auth_flow_delete_response import AuthFlowDeleteResponse as AuthFlowDeleteResponse
from .auth_flow_update_response import AuthFlowUpdateResponse as AuthFlowUpdateResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ApplicationListIdentitiesParams"]


class ApplicationListIdentitiesParams(TypedDict, total=False):
    search: str
    """Search query to filter identities by name"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .mouse_move_params import MouseMoveParams as MouseMoveParams
from .mouse_click_params import MouseClickParams as MouseClickParams
from .all_status_response import AllStatusResponse as AllStatusResponse
from .mouse_move_response import MouseMoveResponse as MouseMoveResponse
from .clipboard_set_params import ClipboardSetParams as ClipboardSetParams
from .keyboard_type_params import KeyboardTypeParams as KeyboardTypeParams
from .mouse_click_response import MouseClickResponse as MouseClickResponse
from .clipboard_set_response import ClipboardSetResponse as ClipboardSetResponse
from .keyboard_type_response import KeyboardTypeResponse as KeyboardTypeResponse
from .recording_list_response import RecordingListResponse as RecordingListResponse
from .keyboard_shortcut_params import KeyboardShortcutParams as KeyboardShortcutParams
from .keyboard_shortcut_response import KeyboardShortcutResponse as KeyboardShortcutResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal, Required, Annotated, TypeAlias, TypedDict

from .._utils import PropertyInfo

__all__ = [
    "TaskCreateParams",
    "BrowserConfiguration",
    "BrowserConfigurationLiveView",
    "BrowserConfigurationProxy",
    "BrowserConfigurationProxyAnchorProxy",
    "BrowserConfigurationProxyCustomProxy",
    "BrowserConfigurationRecording",
    "BrowserConfigurationTimeout",
]


class TaskCreateParams(TypedDict, total=False):
    language: Required[Literal["typescript"]]
    """Programming language for the task"""

    name: Required[str]
    """Task name (letters, numbers, hyphens, and underscores only)"""

    browser_configuration: Annotated[BrowserConfiguration, PropertyInfo(alias="browserConfiguration")]
    """Browser configuration for task execution"""

    code: str
    """Base64 encoded task code (optional)"""

    description: str
    """Optional description of the task"""


class BrowserConfigurationLiveView(TypedDict, total=False):
    """Configuration for live viewing the browser session."""

    read_only: bool
    """Enable or disable read-only mode for live viewing. Defaults to `false`."""


class BrowserConfigurationProxyAnchorProxy(TypedDict, total=False):
    active: Required[bool]

    city: str
    """City name for precise geographic targeting.

    Supported for anchor_proxy only. Can only be used when region is also provided.
    """

    country_code: Literal[
        "af",
        "al",
        "dz",
        "ad",
        "ao",
        "as",
        "ag",
        "ar",
        "am",
        "aw",
        "au",
        "at",
        "az",
        "bs",
        "bh",
        "bb",
        "by",
        "be",
        "bz",
        "bj",
        "bm",
        "bo",
        "ba",
        "br",
        "bg",
        "bf",
        "cm",
        "ca",
        "cv",
        "td",
        "cl",
        "co",
        "cg",
        "cr",
        "ci",
        "hr",
        "cu",
        "cy",
        "cz",
        "dk",
        "dm",
        "do",
        "ec",
        "eg",
        "sv",
        "ee",
        "et",
        "fo",
        "fi",
        "fr",
        "gf",
        "pf",
        "ga",
        "gm",
        "ge",
        "de",
        "gh",
        "gi",
        "gr",
        "gd",
        "gp",
        "gt",
        "gg",
        "gn",
        "gw",
        "gy",
        "ht",
        "hn",
        "hu",
        "is",
        "in",
        "ir",
        "iq",
        "ie",
        "il",
        "it",
        "jm",
        "jp",
        "jo",
        "kz",
        "kw",
        "kg",
        "lv",
        "lb",
        "ly",
        "li",
        "lt",
        "lu",
        "mk",
        "ml",
        "mt",
        "mq",
        "mr",
        "mx",
        "md",
        "mc",
        "me",
        "ma",
        "nl",
        "nz",
        "ni",
        "ng",
        "no",
        "pk",
        "pa",
        "py",
        "pe",
        "ph",
        "pl",
        "pt",
        "pr",
        "qa",
        "ro",
        "lc",
        "sm",
        "sa",
        "sn",
        "rs",
        "sc",
        "sl",
        "sk",
        "si",
        "so",
        "za",
        "kr",
        "es",
        "sr",
        "se",
        "ch",
        "sy",
        "st",
        "tw",
        "tj",
        "tg",
        "tt",
        "tn",
        "tr",
        "tc",
        "ua",
        "ae",
        "us",
        "uy",
        "uz",
        "ve",
        "ye",
        "bd",
        "bw",
        "bn",
        "bi",
        "kh",
        "cn",
        "dj",
        "gq",
        "sz",
        "fj",
        "hk",
        "id",
        "ke",
        "la",
        "ls",
        "lr",
        "mg",
        "mw",
        "my",
        "mv",
        "mn",
        "mz",
        "mm",
        "na",
        "np",
        "nc",
        "ne",
        "om",
        "pg",
        "ru",
        "rw",
        "ws",
        "sg",
        "ss",
        "lk",
        "sd",
        "tz",
        "th",
        "tl",
        "tm",
        "ug",
        "gb",
        "vu",
        "vn",
        "zm",
        "zw",
        "bt",
        "mu",
    ]
    """Supported country codes ISO 2 lowercase

    **On change make sure to update the Proxy type.**
    """

    region: str
    """
    Region code for more specific geographic targeting. The city parameter can only
    be used when region is also provided.
    """

    type: Literal["anchor_proxy", "anchor_residential", "anchor_mobile", "anchor_gov"]
    """**On change make sure to update the country_code.**"""


class BrowserConfigurationProxyCustomProxy(TypedDict, total=False):
    active: Required[bool]

    password: Required[str]
    """Proxy password"""

    server: Required[str]
    """Proxy server address"""

    type: Required[Literal["custom"]]

    username: Required[str]
    """Proxy username"""


BrowserConfigurationProxy: TypeAlias = Union[BrowserConfigurationProxyAnchorProxy, BrowserConfigurationProxyCustomProxy]


class BrowserConfigurationRecording(TypedDict, total=False):
    """Configuration for session recording."""

    active: bool
    """Enable or disable video recording of the browser session. Defaults to `true`."""


class BrowserConfigurationTimeout(TypedDict, total=False):
    """Timeout configurations for the browser session."""

    idle_timeout: int
    """
    The amount of time (in minutes) the browser session waits for new connections
    after all others are closed before stopping. Defaults to `5`.
    """

    max_duration: int
    """Maximum amount of time (in minutes) for the browser to run before terminating.

    Defaults to `20`.
    """


class BrowserConfiguration(TypedDict, total=False):
    """Browser configuration for task execution"""

    initial_url: str
    """The URL to navigate to when the browser session starts.

    If not provided, the browser will load an empty page.
    """

    live_view: BrowserConfigurationLiveView
    """Configuration for live viewing the browser session."""

    proxy: BrowserConfigurationProxy
    """Proxy Documentation available at [Proxy Documentation](/advanced/proxy)"""

    recording: BrowserConfigurationRecording
    """Configuration for session recording."""

    timeout: BrowserConfigurationTimeout
    """Timeout configurations for the browser session."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["IdentityRetrieveResponse"]


class IdentityRetrieveResponse(BaseModel):
    id: Optional[str] = None
    """Unique identifier for the identity"""

    created_at: Optional[datetime] = None
    """Timestamp when the identity was created"""

    metadata: Optional[Dict[str, object]] = None
    """Metadata associated with the identity"""

    name: Optional[str] = None
    """Name of the identity"""

    source: Optional[str] = None
    """Source URL for the identity"""

    status: Optional[Literal["pending", "validated", "failed"]] = None
    """Status of the identity"""

    updated_at: Optional[datetime] = None
    """Timestamp when the identity was last updated"""
